@@ -13,17 +13,15 @@
 #    under the License.
 
 from django.conf import settings
-from troveclient.v1 import client
-
-from openstack_dashboard.api import base
-from oslo_log import log as logging
-
 from horizon.utils import functions as utils
 from horizon.utils.memoized import memoized  # noqa
-
-from keystoneauth1 import loading
 from keystoneauth1 import session
+from keystoneclient.auth import token_endpoint
 from novaclient import client as nova_client
+from openstack_auth import utils as auth_utils
+from openstack_dashboard.api import base
+from oslo_log import log as logging
+from troveclient.v1 import client
 
 # Supported compute versions
 NOVA_VERSIONS = base.APIVersionManager("compute", preferred_version=2)
@@ -39,17 +37,21 @@ LOG = logging.getLogger(__name__)
 def troveclient(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
-    trove_url = base.url_for(request, 'database')
-    c = client.Client(request.user.username,
-                      request.user.token.id,
-                      project_id=request.user.project_id,
-                      auth_url=trove_url,
-                      insecure=insecure,
-                      cacert=cacert,
-                      http_log_debug=settings.DEBUG)
-    c.client.auth_token = request.user.token.id
-    c.client.management_url = trove_url
-    return c
+    endpoint_type = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', 'publicURL')
+    region = request.user.services_region
+
+    endpoint = base.url_for(request, 'database')
+    auth_url, _ = auth_utils.fix_auth_url_version_prefix(
+        settings.OPENSTACK_KEYSTONE_URL)
+    auth = token_endpoint.Token(auth_url, request.user.token.id)
+    verify = not insecure and (cacert or True)
+
+    t_client = client.Client(session=session.Session(auth=auth, verify=verify),
+                             service_type='database',
+                             endpoint_type=endpoint_type,
+                             region_name=region,
+                             endpoint_override=endpoint)
+    return t_client
 
 
 def cluster_list(request, marker=None):
@@ -75,7 +77,7 @@ def cluster_create(request, name, volume, flavor, num_instances,
         if volume > 0:
             instance["volume"] = {'size': volume}
         if nics:
-            instance["nics"] = [{"net-id": nics}]
+            instance["nics"] = [{"network_id": nics}]
         instances.append(instance)
 
     # TODO(saurabhs): vertica needs root password on cluster create
@@ -101,7 +103,7 @@ def cluster_grow(request, cluster_id, new_instances):
         if new_instance.related_to:
             instance["related_to"] = new_instance.related_to
         if new_instance.nics:
-            instance["nics"] = [{'net-id': new_instance.nics}]
+            instance["nics"] = [{'network_id': new_instance.nics}]
         instances.append(instance)
     return troveclient(request).clusters.grow(cluster_id, instances)
 
@@ -219,12 +221,13 @@ def eject_replica_source(request, instance_id):
 
 
 def instance_attach_configuration(request, instance_id, configuration):
-    return troveclient(request).instances.modify(instance_id,
+    return troveclient(request).instances.update(instance_id,
                                                  configuration=configuration)
 
 
 def instance_detach_configuration(request, instance_id):
-    return troveclient(request).instances.modify(instance_id)
+    return troveclient(request).instances.update(instance_id,
+                                                 remove_configuration=True)
 
 
 def database_list(request, instance_id):
@@ -283,17 +286,23 @@ def backup_strategy_delete(request, instance_id=None, project_id=None):
 def nova_client_client(request):
     insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
     cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
-    identity_url = base.url_for(request, 'identity')
-    loader = loading.get_plugin_loader('token')
-    auth = loader.load_from_options(auth_url=identity_url,
-                                    token=request.user.token.id,
-                                    tenant_id=request.user.project_id)
-    sess = session.Session(auth=auth)
-    nova = nova_client.Client(NOVA_VERSION,
-                              session=sess,
-                              insecure=insecure,
-                              cacert=cacert,
-                              http_log_debug=settings.DEBUG)
+    endpoint_type = getattr(settings, 'OPENSTACK_ENDPOINT_TYPE', 'publicURL')
+    region = request.user.services_region
+
+    endpoint = base.url_for(request, 'compute')
+    auth_url, _ = auth_utils.fix_auth_url_version_prefix(
+        settings.OPENSTACK_KEYSTONE_URL)
+    auth = token_endpoint.Token(auth_url, request.user.token.id)
+    verify = not insecure and (cacert or True)
+
+    nova = nova_client.Client(
+        NOVA_VERSION,
+        session=session.Session(auth=auth, verify=verify),
+        endpoint_type=endpoint_type,
+        service_type='compute',
+        region_name=region,
+        endpoint_override=endpoint)
+
     return nova
 
 
@@ -386,19 +395,23 @@ def log_list(request, instance_id):
 
 
 def log_enable(request, instance_id, log_name):
-    return troveclient(request).instances.log_enable(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     enable=True)
 
 
 def log_disable(request, instance_id, log_name):
-    return troveclient(request).instances.log_disable(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     disable=True)
 
 
 def log_publish(request, instance_id, log_name):
-    return troveclient(request).instances.log_publish(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     publish=True)
 
 
 def log_discard(request, instance_id, log_name):
-    return troveclient(request).instances.log_discard(instance_id, log_name)
+    return troveclient(request).instances.log_action(instance_id, log_name,
+                                                     discard=True)
 
 
 def log_tail(request, instance_id, log_name, publish, lines, swift=None):
