@@ -12,18 +12,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import builtins
 
 from django.core import cache
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from trove_dashboard import api
 
 from oslo_serialization import jsonutils
-from six.moves import builtins
 
 
-def get(request, configuration_group_id):
-    if not has_config(configuration_group_id):
+def get(request, configuration_group_id, use_cache=False):
+    if not use_cache or not has_config(configuration_group_id):
         manager = ConfigParamManager(configuration_group_id)
         manager.configuration_get(request)
         cache.cache.set(configuration_group_id, manager)
@@ -51,7 +51,7 @@ def dict_has_changes(original, other):
         return True
 
     diffs = (set(original.keys()) - set(other.keys()))
-    if len(diffs).__nonzero__():
+    if len(diffs) > 0:
         return True
 
     for key in original:
