@@ -14,9 +14,7 @@
 
 from django.forms import ValidationError  # noqa
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
-
-import six
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -45,11 +43,11 @@ class CreateDatabaseForm(forms.SelfHandlingForm):
 
             messages.success(request,
                              _('Created database "%s".') % data['name'])
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:detail",
                                args=(instance,))
-            exceptions.handle(request, _('Unable to create database. %s') %
-                              six.text_type(e), redirect=redirect)
+            exceptions.handle(request, _('Unable to create database.'),
+                              redirect=redirect)
         return True
 
 
@@ -87,10 +85,10 @@ class ResizeVolumeForm(forms.SelfHandlingForm):
                                              data['new_size'])
 
             messages.success(request, _('Resizing volume "%s"') % instance)
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:index")
-            exceptions.handle(request, _('Unable to resize volume. %s') %
-                              six.text_type(e), redirect=redirect)
+            exceptions.handle(request, _('Unable to resize volume.'),
+                              redirect=redirect)
         return True
 
 
@@ -125,10 +123,10 @@ class ResizeInstanceForm(forms.SelfHandlingForm):
             api.trove.instance_resize(request, instance, flavor)
 
             messages.success(request, _('Resizing instance "%s"') % instance)
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:index")
-            exceptions.handle(request, _('Unable to resize instance. %s') %
-                              six.text_type(e), redirect=redirect)
+            exceptions.handle(request, _('Unable to resize instance.'),
+                              redirect=redirect)
         return True
 
 
@@ -143,12 +141,12 @@ class PromoteToReplicaSourceForm(forms.SelfHandlingForm):
             messages.success(
                 request,
                 _('Promoted replica "%s" as the new replica source.') % name)
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:index")
             exceptions.handle(
                 request,
-                _('Unable to promote replica as the new replica source.  "%s"')
-                % six.text_type(e), redirect=redirect)
+                _('Unable to promote replica as the new replica source.'),
+                redirect=redirect)
         return True
 
 
@@ -180,11 +178,11 @@ class CreateUserForm(forms.SelfHandlingForm):
 
             messages.success(request,
                              _('Created user "%s".') % data['name'])
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:detail",
                                args=(instance,))
-            exceptions.handle(request, _('Unable to create user. %s') %
-                              six.text_type(e), redirect=redirect)
+            exceptions.handle(request, _('Unable to create user.'),
+                              redirect=redirect)
         return True
 
     def _get_databases(self, data):
@@ -229,11 +227,11 @@ class EditUserForm(forms.SelfHandlingForm):
 
             messages.success(request,
                              _('Updated user "%s".') % data['user_name'])
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:detail",
                                args=(instance,))
-            exceptions.handle(request, _('Unable to update user. %s') %
-                              six.text_type(e), redirect=redirect)
+            exceptions.handle(request, _('Unable to update user.'),
+                              redirect=redirect)
         return True
 
     def clean(self):
@@ -277,9 +275,48 @@ class AttachConfigurationForm(forms.SelfHandlingForm):
 
             messages.success(request, _('Attaching Configuration group "%s"')
                              % instance_id)
-        except Exception as e:
+        except Exception:
             redirect = reverse("horizon:project:databases:index")
             exceptions.handle(request, _('Unable to attach configuration '
-                                         'group. %s')
-                              % six.text_type(e), redirect=redirect)
+                                         'group.'),
+                              redirect=redirect)
+        return True
+
+
+class UpdateInstanceForm(forms.SelfHandlingForm):
+    instance_id = forms.CharField(widget=forms.HiddenInput())
+    instance_name = forms.CharField(label=_("Name"))
+    allowed_cidrs = forms.MultiIPField(
+        label=_("Allowed CIDRs"),
+        required=False,
+        help_text=_("Classless Inter-Domain Routing "
+                    "(e.g. 192.168.0.0/24, or "
+                    "2001:db8::/128). Can enter multiple values separating"
+                    "by a comma"),
+        version=forms.IPv4 | forms.IPv6,
+        mask=True,
+        widget=forms.TextInput())
+
+    def __init__(self, request, *args, **kwargs):
+        super(UpdateInstanceForm, self).__init__(request, *args, **kwargs)
+        instance_id = kwargs.get('initial', {}).get('instance_id')
+        self.fields['instance_id'].initial = instance_id
+
+    def handle(self, request, data):
+        instance_id = data.get('instance_id')
+        allowed_cidrs = data.get('allowed_cidrs')
+        instance_name = data.get('instance_name')
+        update_kwargs = {'name': instance_name}
+        if allowed_cidrs:
+            update_kwargs['allowed_cidrs'] = allowed_cidrs.split(',')
+        try:
+            api.trove.instance_update(request, instance_id, **update_kwargs)
+
+            messages.success(request, _('Instance "%s" successfully updated.')
+                             % instance_name)
+        except Exception:
+            redirect = reverse("horizon:project:databases:index")
+            exceptions.handle(request, _('Unable to update instance "%s".'
+                                         % instance_id),
+                              redirect=redirect)
         return True
