@@ -14,7 +14,7 @@
 
 from django.conf import settings
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -626,9 +626,8 @@ class LaunchInstance(workflows.Workflow):
     def _get_nics(self, context):
         netids = context.get('network_id', None)
         if netids:
-            return [{"net-id": netid} for netid in netids]
-        else:
-            return None
+            return [{"network_id": netid} for netid in netids]
+        return None
 
     def _get_volume_type(self, context):
         volume_type = None
